.. _recipe_asr.workflow:

asr.workflow
============


.. contents:: Contents
   :local:

Summary
-------

This is the documentation for :py:mod:`asr.workflow`-recipe.
This recipe is comprised of a single step, namely:

  - :py:func:`asr.workflow.main`

Run this recipe through the CLI interface

.. code-block:: console

   $ asr run asr.workflow

or as a python module

.. code-block:: console

   $ python -m asr.workflow

Detailed description
--------------------
Run workflow module..

Steps
-----


asr.workflow
^^^^^^^^^^^^
.. autofunction:: asr.workflow.main
   